DEFAULT_API_URL: str = "http://127.0.0.1:8000/api/"

TERMINAL_SECRET_KEY_PREFIX = "tr_sk__"
TERMINAL_WEBHOOK_SECRET_KEY_PREFIX = "tr_wsk__"

FEATURE_USAGE_LIMIT_EXCEEDED_ERROR_CODE = "FEATURE_USAGE_LIMIT_EXCEEDED_001"
